ic.fit(densi, models, N, ic, averaging = averaging, normalized = TRUE,
rasch = FALSE)make.hierarchical.term.sets().densi by N and
then sum over the resulting vector, you should get the
effective sample size.flat.IC except that it is designed to take
in a local average instead of a full capture-recapture
dataset