Compute model weights according to the information
criterion scores of each model.
Usage
ic.wghts(scores)
Arguments
scores
The information criterion scores.
Value
A vector of weights, which can be interpreted (loosely) as
the relative desireability of the models corresponding to
the weights
Details
The formula is quite simple: Identify the smallest (best)
score among the various models. Subtract this minimum
value from all of the scores, and call the resulting set of
scores $s$. Compute exp(-0.5 s) for all the scores, and
normalize the resulting vector to obtain the vector of
model weights