glm that does only parameter
estimation. This attempts to mimic the IRLS routine invoked
by glm, without returning extra ``baggage" such as
standard errors.pirls(predictors, data, epsilon = 1e-08, iter.max = 25, normalized = TRUE)epsilon the control parameters
for glm.fit.predictors argument, in that orderpirls is to obtain speed, for
the special circumstance in which one must fit gazillions
of Poisson regression models, where the only quantity of
interested is the point estimates of the regression
coefficients. Matrix inversion is one of the most time
consuming steps in the function, and the overall speed can
be improved by about 20 percent by modifying the source
code to replace the solve() command with
.Internal(La_solve()).