Learn R Programming

lllcrc (version 1.2)

summarize.by.factors: Summarize LLLM by factor

Description

Compute the number of observations and the average estimated rate of missingness for each combination of a set of categorical covariates

Usage

summarize.by.factors(dat, vars)

Arguments

dat
The dat object in the output of lllcrc or vgam.crc
vars
A vector of variable names, where the names are in the form "x.dis...." as in the output of format.data

Value

A data frame