vgam.crc(dat, models = make.hierarchical.term.sets(k = attributes(dt)$k), sdf,
llform = NULL, round.vars = NULL, rounding.scale = NULL,
boot.control = NULL)format.datamake.hierarchical.term.sets(k =
attributes(dat)$k)AICc.vgam
is used to select the best set of terms among the
candidate sets that are proposed by the functmicro.post.stratify,
which is called within vgam.crc.micro.post.stratify, which is called within
vgam.crc.micro.post.stratify, with
estimated local rates of missingness appended as an extra
column labeled pi0. In addition, mct
(multinomial cell count) gives the number of observed units
with that distinct covariate vector, and cpi0
(cumulative number missing) gives the the product of
pi0 with mct, such that summing over this
vectorized product is exactly the Horvitz-Thompson style
sum in capture recapture.AICc.vgamvgam
function in package VGAM for detailsvgam.crc and has attributes
cont.x and conteg.x, which relate the
continuous and categorical variables in the modelZwane E and Heijden Pvd (2004). "Semiparametric models for capture-recapture studies with covariates." Computational Statistics & Data Analysis, 47, pp. 729-743.